<?php

namespace B2buy\Agreement\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use B2buy\Agreement\Http\Requests\MasterSupplierRequest;
use B2buy\Agreement\Interfaces\MasterSupplierRepositoryInterface;
use B2buy\Agreement\Models\MasterSupplier;
use B2buy\Agreement\Forms\MasterSupplier as Form;

/**
 * APIController  class for master_supplier.
 */
class MasterSupplierAPIController extends BaseController
{

    /**
     * Initialize master_supplier resource controller.
     *
     * @param type MasterSupplierRepositoryInterface $master_supplier
     *
     * @return null
     */
    public function __construct(MasterSupplierRepositoryInterface $master_supplier)
    {
        parent::__construct();
        $this->repository = $master_supplier;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\Agreement\Repositories\Criteria\MasterSupplierResourceCriteria::class);
    }

    /**
     * Display a list of master_supplier.
     *
     * @return Response
     */
    public function index(MasterSupplierRequest $request)
    {
        return $this->repository
            ->setPresenter(\B2buy\Agreement\Repositories\Presenter\MasterSupplierPresenter::class)
            ->paginate();
    }

    /**
     * Display master_supplier.
     *
     * @param Request $request
     * @param Model   $master_supplier
     *
     * @return Response
     */
    public function show(MasterSupplierRequest $request, MasterSupplier $master_supplier)
    {
        return $master_supplier->setPresenter(\B2buy\Agreement\Repositories\Presenter\MasterSupplierListPresenter::class);
        ;
    }

    /**
     * Create new master_supplier.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MasterSupplierRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('agreement::master_supplier.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('agreement/master_supplier/' . $master_supplier->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('agreement/master_supplier');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the master_supplier.
     *
     * @param Request $request
     * @param Model   $master_supplier
     *
     * @return Response
     */
    public function update(MasterSupplierRequest $request, MasterSupplier $master_supplier)
    {
        try {
            $data = $request->all();

            $master_supplier->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('agreement::master_supplier.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('agreement/master_supplier/' . $master_supplier->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('agreement/master_supplier/' . $master_supplier->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the master_supplier.
     *
     * @param Model   $master_supplier
     *
     * @return Response
     */
    public function destroy(MasterSupplierRequest $request, MasterSupplier $master_supplier)
    {
        try {
            $master_supplier->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('agreement::master_supplier.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('agreement/master_supplier/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('agreement/master_supplier/' . $master_supplier->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
