<?php

namespace B2buy\Agreement\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\Agreement\Http\Requests\MasterSupplierRequest;
use B2buy\Agreement\Models\MasterSupplier;

/**
 * Admin web controller class.
 */
class MasterSupplierWorkflowController extends BaseController
{

    /**
     * Workflow controller function for master_supplier.
     *
     * @param Model   $master_supplier
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MasterSupplierRequest $request, MasterSupplier $master_supplier, $step)
    {

        try {

            $master_supplier->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('agreement::master_supplier.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/master_supplier/master_supplier/' . $master_supplier->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/master_supplier/master_supplier/' . $master_supplier->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for master_supplier.
     *
     * @param Model   $master_supplier
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(MasterSupplier $master_supplier, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $master_supplier->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('agreement::master_supplier.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('agreement::admin.master_supplier.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('agreement::admin.master_supplier.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('agreement::admin.master_supplier.message', $data)->render();

        }

    }
}
