<?php

namespace B2buy\Agreement\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Agreement\Models\MasterSupplier;

class MasterSupplierPolicy
{

    /**
     * Determine if the given user can view the master_supplier.
     *
     * @param UserPolicy $user
     * @param MasterSupplier $master_supplier
     *
     * @return bool
     */
    public function view(UserPolicy $user, MasterSupplier $master_supplier)
    {
        if ($user->canDo('agreement.master_supplier.view') && $user->isAdmin()) {
            return true;
        }

        return $master_supplier->user_id == user_id() && $master_supplier->user_type == user_type();
    }

    /**
     * Determine if the given user can create a master_supplier.
     *
     * @param UserPolicy $user
     * @param MasterSupplier $master_supplier
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('agreement.master_supplier.create');
    }

    /**
     * Determine if the given user can update the given master_supplier.
     *
     * @param UserPolicy $user
     * @param MasterSupplier $master_supplier
     *
     * @return bool
     */
    public function update(UserPolicy $user, MasterSupplier $master_supplier)
    {
        if ($user->canDo('agreement.master_supplier.edit') && $user->isAdmin()) {
            return true;
        }

        return $master_supplier->user_id == user_id() && $master_supplier->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given master_supplier.
     *
     * @param UserPolicy $user
     * @param MasterSupplier $master_supplier
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MasterSupplier $master_supplier)
    {
        return $master_supplier->user_id == user_id() && $master_supplier->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given master_supplier.
     *
     * @param UserPolicy $user
     * @param MasterSupplier $master_supplier
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MasterSupplier $master_supplier)
    {
        if ($user->canDo('agreement.master_supplier.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given master_supplier.
     *
     * @param UserPolicy $user
     * @param MasterSupplier $master_supplier
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MasterSupplier $master_supplier)
    {
        if ($user->canDo('agreement.master_supplier.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
