<?php

namespace B2buy\Agreement\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\Agreement\Models\MasterSupplier;

class MasterSupplierAction
{
    /**
     * Perform the complete action.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return MasterSupplier
     */
    public function complete(MasterSupplier $master_supplier)
    {
        try {
            $master_supplier->status = 'complete';
            return $master_supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return MasterSupplier
     */public function verify(MasterSupplier $master_supplier)
    {
        try {
            $master_supplier->status = 'verify';
            return $master_supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return MasterSupplier
     */public function approve(MasterSupplier $master_supplier)
    {
        try {
            $master_supplier->status = 'approve';
            return $master_supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return MasterSupplier
     */public function publish(MasterSupplier $master_supplier)
    {
        try {
            $master_supplier->status = 'publish';
            return $master_supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return MasterSupplier
     */
    public function archive(MasterSupplier $master_supplier)
    {
        try {
            $master_supplier->status = 'archive';
            return $master_supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return MasterSupplier
     */
    public function unpublish(MasterSupplier $master_supplier)
    {
        try {
            $master_supplier->status = 'unpublish';
            return $master_supplier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
