<?php

namespace B2buy\Agreement\Workflow;

use B2buy\Agreement\Models\MasterSupplier;
use Validator;

class MasterSupplierValidator
{

    /**
     * Determine if the given master_supplier is valid for complete status.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return bool / Validator
     */
    public function complete(MasterSupplier $master_supplier)
    {
        return Validator::make($master_supplier->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given master_supplier is valid for verify status.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return bool / Validator
     */
    public function verify(MasterSupplier $master_supplier)
    {
        return Validator::make($master_supplier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given master_supplier is valid for approve status.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return bool / Validator
     */
    public function approve(MasterSupplier $master_supplier)
    {
        return Validator::make($master_supplier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given master_supplier is valid for publish status.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return bool / Validator
     */
    public function publish(MasterSupplier $master_supplier)
    {
        return Validator::make($master_supplier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given master_supplier is valid for archive status.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return bool / Validator
     */
    public function archive(MasterSupplier $master_supplier)
    {
        return Validator::make($master_supplier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given master_supplier is valid for unpublish status.
     *
     * @param MasterSupplier $master_supplier
     *
     * @return bool / Validator
     */
    public function unpublish(MasterSupplier $master_supplier)
    {
        return Validator::make($master_supplier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
